@@ -1,7 +1,6 @@
 package Audio::Nama::Assign;
-use Modern::Perl;
+use v5.36;
 our $VERSION = 1.0;
-use 5.008;
 use feature 'state';
 use strict;
 use warnings;
@@ -81,7 +80,6 @@ use Carp;
 	$volume_control_operator 		$config->{volume_control_operator}
 	$serialize_formats  	        $config->{serialize_formats}
 	$use_git						$config->{use_git}
-	$autosave						$config->{autosave}
 	$beep_command 					$config->{beep_command}
 	$hotkey_beep					$config->{hotkey_beep}
 	$eager							$mode->{eager}
@@ -90,6 +88,8 @@ use Carp;
 	$hotkeys						$config->{hotkeys}
 	$new_track_rw					$config->{new_track_rw}
 	$hotkeys_always					$config->{hotkeys_always}
+	$hotkey_playback_jumpsize_seconds   $config->{hotkey_playback_jumpsize_seconds}
+	$seek_end_margin			   $config->{seek_end_margin}
 	$use_pager     					$config->{use_pager}
 	$use_placeholders  				$config->{use_placeholders}
     $edit_playback_end_margin  		$config->{edit_playback_end_margin}
@@ -113,6 +113,8 @@ use Carp;
 	$loop_chain_channel_width 	$config->{loop_chain_channel_width}
 	$waveform_pixels_per_second		$config->{waveform_pixels_per_second}
 	$display_waveform					$config->{display_waveform}
+	$ticks_per_quarter_note 		$config->{ticks_per_quarter_note}
+	$use_metronome					$config->{use_metronome}
 
 ) };
 sub var_map {  $var_map } # to allow outside access while keeping
@@ -128,7 +130,7 @@ sub assign {
   #	class => $class
   #	);
 
-	logsub("&assign");
+	logsub((caller(0))[3]);
 	
 	my %h = @_; # parameters appear in %h
 	my $class;
@@ -280,7 +282,7 @@ $project
 
 );
 sub assign_singletons {
-	logsub('&assign_singletons');
+	logsub((caller(0))[3]);
 	my $ref = shift;
 	my $data = $ref->{data} or die "expected data got undefined";
 	my $class = $ref->{class} // 'Audio::Nama';
@@ -338,7 +340,7 @@ sub serialize_and_write {
 			$ 				# end anchor
 			/x;
 sub serialize {
-	logsub("&serialize");
+	logsub((caller(0))[3]);
 
 	my %h = @_;
 	my @vars = @{ $h{vars} };
@@ -412,7 +414,7 @@ sub serialize {
 }
 
 sub json_out {
-	logsub("&json_out");
+	logsub((caller(0))[3]);
 	my $data_ref = shift;
 	my $type = ref $data_ref;
 	croak "attempting to code wrong data type: $type"
@@ -421,7 +423,7 @@ sub json_out {
 }
 
 sub json_in {
-	logsub("&json_in");
+	logsub((caller(0))[3]);
 	my $json = shift;
 	my $data_ref = decode_json($json);
 	$data_ref
@@ -429,7 +431,7 @@ sub json_in {
 
 sub yaml_in {
 	
-	# logsub("&yaml_in");
+	# logsub((caller(0))[3]);
 	my $input = shift;
 	my $yaml = $input =~ /\n/ # check whether file or text
 		? $input 			# yaml text
