@@ -1,7 +1,8 @@
 {
 package Audio::Nama::BusUtil;
 use Role::Tiny;
-use Modern::Perl;
+use v5.36;
+our $VERSION = 1.0;
 use Audio::Nama::Globals qw(%tn %bn PLAY OFF MON);
 
 sub version_has_edits { 
