@@ -1,5 +1,6 @@
 package Audio::Nama::Lat;
-use Modern::Perl;
+use v5.36;
+our $VERSION = 1.0;
 our @ISA;
 use Data::Dumper::Concise;
 use overload '+' => \&add_latency,
