@@ -1,7 +1,7 @@
 # ------------ Set region for current track ----------
 
 package Audio::Nama;
-use Modern::Perl; use Carp;
+use v5.36; use Carp;
 
 sub set_region {
 	my ($beg, $end) = @_;
