@@ -1,6 +1,7 @@
 package Audio::Nama::TrackLatency;
 use Role::Tiny;
-use Modern::Perl;
+use v5.36;
+our $VERSION = 1.0;
 use Audio::Nama::Globals qw($setup);
 
 sub latency_offset {
